==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_yo_BJ.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_yo_BJ extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Diami ti Awon Or\u00edl\u025b\u0301\u00e8de Arabu" },
            { "aoa", "Wansa ti Or\u00edl\u025b\u0301\u00e8de \u00c0ng\u00f3l\u00e0" },
            { "aud", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de \u00c1str\u00e0l\u00ec\u00e1" },
            { "bhd", "Dina ti Or\u00edl\u025b\u0301\u00e8de B\u00e1r\u00e1n\u00ec" },
            { "bif", "Faransi ti Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9r\u00fand\u00ec" },
            { "brl", "Ow\u00f3 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 Brazil" },
            { "bwp", "Pula ti Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300t\u00ecs\u00faw\u00e1n\u00e0" },
            { "cad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de K\u00e1n\u00e1d\u00e0" },
            { "cdf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "chf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Siwisi" },
            { "cny", "Reminibi ti Or\u00edl\u025b\u0301\u00e8de sh\u00e1\u00edn\u00e0" },
            { "cve", "Kabofediano ti Or\u00edl\u025b\u0301\u00e8de Esuodo" },
            { "djf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Dibouti" },
            { "dzd", "Dina ti Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9g\u00e8r\u00ed\u00e1n\u00ec" },
            { "egp", "p\u0254\u0254n ti Or\u00edl\u025b\u0301\u00e8de Egipiti" },
            { "ern", "Nakifa ti Or\u00edl\u025b\u0301\u00e8de Eriteriani" },
            { "etb", "Biri ti Or\u00edl\u025b\u0301\u00e8de Eutopia" },
            { "gbp", "P\u0254\u0301n-\u00f9n ti Oril\u025b\u0300-\u00e8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "ghc", "shidi ti Or\u00edl\u025b\u0301\u00e8de Gana" },
            { "gmd", "Dalasi ti Or\u00edl\u025b\u0301\u00e8de Gamibia" },
            { "gns", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Gini" },
            { "inr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Indina" },
            { "jpy", "Yeni ti Or\u00edl\u025b\u0301\u00e8de Japani" },
            { "kes", "shiili ti Or\u00edl\u025b\u0301\u00e8de Kenya" },
            { "kmf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de shomoriani" },
            { "lrd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Liberia" },
            { "lsl", "Loti ti Or\u00edl\u025b\u0301\u00e8de Lesoto" },
            { "lyd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Libiya" },
            { "mad", "Dirami ti Or\u00edl\u025b\u0301\u00e8de Moroko" },
            { "mga", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Malagasi" },
            { "mro", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania (1973\u20132017)" },
            { "mru", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania" },
            { "mur", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Maritiusi" },
            { "mwk", "Kasha ti Or\u00edl\u025b\u0301\u00e8de Malawi" },
            { "mzm", "Metika ti Or\u00edl\u025b\u0301\u00e8de Mosamibiki" },
            { "nad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Namibia" },
            { "ngn", "N\u00e1\u00ecr\u00e0 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 N\u00e0\u00ecj\u00edr\u00ed\u00e0" },
            { "rub", "Ow\u00f3 ruble ti il\u025b\u0300 R\u0254\u0301sh\u00ed\u00e0" },
            { "rwf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Ruwanda" },
            { "sar", "Riya ti Or\u00edl\u025b\u0301\u00e8de Saudi" },
            { "scr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Sayiselesi" },
            { "sdg", "Dina ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "sdp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "shp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de \u0323Elena" },
            { "sos", "Sile ti Or\u00edl\u025b\u0301\u00e8de Somali" },
            { "std", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe (1977\u20132017)" },
            { "stn", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe" },
            { "tnd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Tunisia" },
            { "tzs", "Sile ti Or\u00edl\u025b\u0301\u00e8de Tansania" },
            { "ugx", "Siile ti Or\u00edl\u025b\u0301\u00e8de Uganda" },
            { "usd", "D\u0254\u0301l\u00e0" },
            { "xaf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BEKA" },
            { "xof", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BIKEAO" },
            { "xxx", "ow\u00f3n\u00edn\u00e1 \u00e0\u00ecm\u0254\u0300" },
            { "zar", "Randi ti Or\u00edl\u025b\u0301\u00e8de Ariwa Afirika" },
            { "zmk", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia (1968\u20132012)" },
            { "zmw", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia" },
            { "zwd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Siibabuwe" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_yo_BJ.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_yo_BJ extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Diami ti Awon Or\u00edl\u025b\u0301\u00e8de Arabu" },
            { "all", "L\u025b\u0301k\u025b\u0300 \u00c0l\u00ecb\u00e9n\u00ed\u00e0" },
            { "amd", "D\u00edr\u00e0\u00e0m\u00f9 \u00c0m\u025b\u0301n\u00ed\u00e0" },
            { "aoa", "Wansa ti Or\u00edl\u025b\u0301\u00e8de \u00c0ng\u00f3l\u00e0" },
            { "ars", "P\u025b\u0301s\u00f2 Ag\u025bnt\u00edn\u00e0" },
            { "aud", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de \u00c1str\u00e0l\u00ec\u00e1" },
            { "bbd", "D\u0254\u0301l\u00e0 B\u00e1b\u00e1d\u0254\u0300\u0254\u0300s\u00ec" },
            { "bdt", "T\u00e1k\u00e0 B\u00e1\u0144g\u00edl\u00e1d\u025b\u0300\u025b\u0300sh\u00ec" },
            { "bgn", "Ow\u00f3 L\u025b\u0301f\u00ec B\u0254\u0300l\u00ecg\u00e9r\u00ed\u00e0" },
            { "bhd", "Dina ti Or\u00edl\u025b\u0301\u00e8de B\u00e1r\u00e1n\u00ec" },
            { "bif", "Faransi ti Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9r\u00fand\u00ec" },
            { "bmd", "D\u0254\u0301l\u00e0 B\u025b\u0300m\u00fad\u00e0" },
            { "bnd", "D\u0254\u0301l\u00e0 B\u00f9r\u00f9n\u00e9\u00ec" },
            { "bob", "B\u0254lifi\u00e1n\u00f2 B\u0254\u0300l\u00edf\u00ed\u00e0" },
            { "brl", "Ow\u00f3 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 Brazil" },
            { "bsd", "D\u0254\u0301l\u00e0 B\u00e0h\u00e1m\u00e0" },
            { "btn", "\u00ccng\u0254\u0301t\u00edr\u0254\u0300m\u00f9 B\u00fat\u00e0\u00e0n\u00ec" },
            { "bwp", "Pula ti Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300t\u00ecs\u00faw\u00e1n\u00e0" },
            { "byn", "R\u0254\u0301b\u00f9 B\u025b\u0300l\u00e1r\u00f9\u00f9s\u00ec" },
            { "bzd", "D\u0254\u0301l\u00e0 B\u025b\u0300l\u00eds\u00e8" },
            { "cad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de K\u00e1n\u00e1d\u00e0" },
            { "cdf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "chf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Siwisi" },
            { "clp", "P\u025b\u0301s\u00f2 Sh\u00edl\u00e8" },
            { "cny", "Reminibi ti Or\u00edl\u025b\u0301\u00e8de sh\u00e1\u00edn\u00e0" },
            { "cop", "P\u025b\u0301s\u00f2 K\u00f2l\u00f3\u1e3fb\u00ed\u00e0" },
            { "crc", "K\u00f3l\u0254\u0301\u0254\u0300n\u00ec Kosita R\u00edk\u00e0" },
            { "cuc", "P\u025b\u0301s\u00f2 Y\u00edy\u00edpad\u00e0 K\u00fab\u00e0" },
            { "cup", "P\u025b\u0301s\u00f2 K\u00fab\u00e0" },
            { "cve", "Kabofediano ti Or\u00edl\u025b\u0301\u00e8de Esuodo" },
            { "czk", "Koruna Sh\u025b\u0301\u025b\u0300k\u00ec" },
            { "djf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Dibouti" },
            { "dkk", "K\u00edr\u00f3n\u00ec D\u00e1n\u00edsh\u00ec" },
            { "dop", "P\u025b\u0301s\u00f2 D\u00f2n\u00edn\u00edk\u00e0" },
            { "dzd", "Dina ti Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9g\u00e8r\u00ed\u00e1n\u00ec" },
            { "egp", "p\u0254\u0254n ti Or\u00edl\u025b\u0301\u00e8de Egipiti" },
            { "ern", "Nakifa ti Or\u00edl\u025b\u0301\u00e8de Eriteriani" },
            { "etb", "Biri ti Or\u00edl\u025b\u0301\u00e8de Eutopia" },
            { "fjd", "D\u0254\u0301l\u00e0 F\u00edj\u00ec" },
            { "fkp", "P\u0254\u0301n-\u00f9n Er\u00e9k\u00f9s\u00f9 Falkland" },
            { "gbp", "P\u0254\u0301n-\u00f9n ti Oril\u025b\u0300-\u00e8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "gel", "L\u00e1r\u00ec J\u0254\u0301j\u00ed\u00e0" },
            { "ghc", "shidi ti Or\u00edl\u025b\u0301\u00e8de Gana" },
            { "gip", "P\u0254\u0301n-\u00f9n Gibraltar" },
            { "gmd", "Dalasi ti Or\u00edl\u025b\u0301\u00e8de Gamibia" },
            { "gns", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Gini" },
            { "gtq", "K\u00fa\u025b\u0301t\u00eds\u00e0\u00e0l\u00ec Guatim\u00edl\u00e0" },
            { "gyd", "D\u0254\u0301l\u00e0 G\u00f9y\u00e1n\u00e0" },
            { "hkd", "D\u0254\u0301l\u00e0 Hong Kong" },
            { "hnl", "L\u025bmip\u00edr\u00e0 \u0186\u0301\u0144d\u00far\u00e0" },
            { "htg", "G\u0254\u0301d\u00ec \u00c0\u00edt\u00ec" },
            { "huf", "F\u0254\u0301r\u00ed\u01f9t\u00ec H\u0254\u0300ng\u00e9r\u00ed" },
            { "ils", "Sh\u00e9k\u00e9l\u00ec Tuntun \u00cds\u00edr\u025b\u0300\u025b\u0300l\u00ec" },
            { "inr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Indina" },
            { "jmd", "D\u0254\u0301l\u00e0 J\u00e0m\u00e1\u00edk\u00e0" },
            { "jod", "D\u00edn\u00e1r\u00ec J\u0254\u0301d\u00e0\u00e0n\u00ec" },
            { "jpy", "Yeni ti Or\u00edl\u025b\u0301\u00e8de Japani" },
            { "kes", "shiili ti Or\u00edl\u025b\u0301\u00e8de Kenya" },
            { "khr", "R\u00e1y\u00f2 K\u00e0m\u0300b\u0254\u0301d\u00ed\u00e0" },
            { "kmf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de shomoriani" },
            { "kpw", "W\u0254\u0301\u0254\u0300n\u00f9 \u00c0r\u00edw\u00e1 K\u00f2r\u00ed\u00e0" },
            { "krw", "W\u0254\u0301\u0254\u0300n\u00f9 G\u00fa\u00fas\u00f9 K\u00f2r\u00ed\u00e0" },
            { "kyd", "D\u0254\u0301l\u00e0 Er\u00e9k\u00f9s\u00f9 Cayman" },
            { "kzt", "T\u025bng\u00e9 Kasak\u00eds\u00edt\u00e0\u00e0n\u00ec" },
            { "lbp", "P\u0254\u0301n-\u00f9n Lebanese" },
            { "lrd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Liberia" },
            { "lsl", "Loti ti Or\u00edl\u025b\u0301\u00e8de Lesoto" },
            { "lyd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Libiya" },
            { "mad", "Dirami ti Or\u00edl\u025b\u0301\u00e8de Moroko" },
            { "mga", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Malagasi" },
            { "mkd", "D\u025b\u0301n\u00e0 Masid\u00f3n\u00ed\u00e0" },
            { "mro", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania (1973\u20132017)" },
            { "mru", "Ouguiya ti Or\u00edl\u025b\u0301\u00e8de Maritania" },
            { "mur", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Maritiusi" },
            { "mvr", "R\u00faf\u00ecy\u00e1 M\u0254\u0300l\u00ecd\u00edf\u00e0" },
            { "mwk", "Kasha ti Or\u00edl\u025b\u0301\u00e8de Malawi" },
            { "mxn", "P\u025b\u0301s\u00f2 M\u025b\u0301s\u00edk\u00f2" },
            { "myr", "R\u00edng\u00ect\u00ec M\u00e0l\u00e9sh\u00ed\u00e0" },
            { "mzm", "Metika ti Or\u00edl\u025b\u0301\u00e8de Mosamibiki" },
            { "mzn", "M\u025b\u0301t\u00edk\u00e0\u00e0l\u00ec M\u00f2s\u00e1\u1e3fb\u00ed\u00eck\u00ec" },
            { "nad", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Namibia" },
            { "ngn", "N\u00e1\u00ecr\u00e0 ti Or\u00edl\u025b\u0300-\u00e8d\u00e8 N\u00e0\u00ecj\u00edr\u00ed\u00e0" },
            { "nio", "K\u0254\u0300d\u00f3b\u00e0 Naikar\u00e1g\u00fa\u00e0" },
            { "nok", "K\u00edr\u00f3n\u00ec N\u0254\u0301\u0254\u0301w\u00e8" },
            { "npr", "R\u00fap\u00ec\u00ec N\u025b\u0335\u0301p\u00e0\u00e0l\u00ec" },
            { "nzd", "D\u0254\u0301l\u00e0 New Zealand" },
            { "pln", "S\u00edl\u0254\u0300t\u00ec P\u0254\u0301l\u00edsh\u00ec" },
            { "rub", "Ow\u00f3 ruble ti il\u025b\u0300 R\u0254\u0301sh\u00ed\u00e0" },
            { "rwf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de Ruwanda" },
            { "sar", "Riya ti Or\u00edl\u025b\u0301\u00e8de Saudi" },
            { "sbd", "D\u0254\u0301l\u00e0 Er\u00e9k\u00f9s\u00f9 S\u0254\u0301l\u00f3m\u0254\u0301n\u00ec" },
            { "scr", "Rupi ti Or\u00edl\u025b\u0301\u00e8de Sayiselesi" },
            { "sdg", "Dina ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "sdp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "sgd", "D\u0254\u0301l\u00e0 S\u00edng\u00e1p\u0254\u0300" },
            { "shp", "P\u0254\u0254un ti Or\u00edl\u025b\u0301\u00e8de \u0323Elena" },
            { "sos", "Sile ti Or\u00edl\u025b\u0301\u00e8de Somali" },
            { "srd", "D\u0254\u0301l\u00e0 S\u00far\u00edn\u00e1m\u00ec" },
            { "ssp", "P\u0254\u0301n-\u00f9n G\u00fa\u00fas\u00f9 S\u00f9d\u00e1\u00e0n\u00ec" },
            { "std", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe (1977\u20132017)" },
            { "stn", "Dobira ti Or\u00edl\u025b\u0301\u00e8de Sao tome Ati Pirisipe" },
            { "syp", "P\u0254\u0301n-\u00f9n S\u00edr\u00ec\u00e0" },
            { "tmt", "M\u00e1n\u00e0\u00e0t\u00ec T\u0254kim\u025bn\u00edst\u00e0\u00e0n\u00ec" },
            { "tnd", "Dina ti Or\u00edl\u025b\u0301\u00e8de Tunisia" },
            { "try", "L\u00edr\u00e0 T\u0254\u0301k\u00ec" },
            { "ttd", "D\u0254\u0301l\u00e0 Trinidad & Tobago" },
            { "twd", "D\u0254\u0301l\u00e0 T\u00e0\u00ecw\u00e1n\u00ec Tuntun" },
            { "tzs", "Sile ti Or\u00edl\u025b\u0301\u00e8de Tansania" },
            { "uah", "\u0186rifin\u00edy\u00e0 Yukir\u00e9n\u00ed\u00e0" },
            { "ugx", "Siile ti Or\u00edl\u025b\u0301\u00e8de Uganda" },
            { "usd", "D\u0254\u0301l\u00e0" },
            { "uyu", "P\u025b\u0301s\u00f2 \u00dar\u00fag\u00faw\u00e8" },
            { "uzs", "S\u00f3m\u00fa Usib\u025bk\u00eds\u00edt\u00e0\u00e0n\u00ec" },
            { "ves", "B\u0254\u0300l\u00edf\u00e0 F\u025bn\u025bsu\u025b\u0301l\u00e0" },
            { "xaf", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BEKA" },
            { "xcd", "D\u0254\u0301l\u00e0 Il\u00e0 O\u00f2r\u00f9n Kar\u00edb\u00ed\u00e0" },
            { "xof", "Faransi ti Or\u00edl\u025b\u0301\u00e8de BIKEAO" },
            { "xxx", "ow\u00f3n\u00edn\u00e1 \u00e0\u00ecm\u0254\u0300" },
            { "yer", "R\u00e1y\u00f2 Y\u025b\u0301m\u025b\u0300n\u00ec" },
            { "zar", "Randi ti Or\u00edl\u025b\u0301\u00e8de Ariwa Afirika" },
            { "zmk", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia (1968\u20132012)" },
            { "zmw", "Kawasha ti Or\u00edl\u025b\u0301\u00e8de Saabia" },
            { "zwd", "D\u0254la ti Or\u00edl\u025b\u0301\u00e8de Siibabuwe" },
        };
        return data;
    }
}
